==========================
``psyclone.psyir.backend``
==========================

.. automodule:: psyclone.psyir.backend

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.psyir.backend.c
   psyclone.psyir.backend.fortran
   psyclone.psyir.backend.language_writer
   psyclone.psyir.backend.opencl
   psyclone.psyir.backend.sir
   psyclone.psyir.backend.sympy_writer
   psyclone.psyir.backend.visitor

.. currentmodule:: psyclone.psyir.backend
